Ext.namespace('Zarafa.plugins.sugarcrm');

/**
 * @class Zarafa.plugins.sugarcrm.SugarCRMPlugin
 * @extends Zarafa.core.Plugin
 *
 * SugarCRM integration plugin.
 * Allows to archive selected record to SugarCRM.
 */
Zarafa.plugins.sugarcrm.SugarCRMPlugin = Ext.extend(Zarafa.core.Plugin, {

	/**
	 * @constructor
	 * @param {Object} config Configuration object
	 */
	constructor : function(config) {
		config = config || {};
		Ext.applyIf(config, {
			name : 'sugarcrm'
		});
		Zarafa.plugins.sugarcrm.SugarCRMPlugin.superclass.constructor.call(this, config);
		this.init();
	},

	/**
	 * Called after constructor.
	 * Registers insertion point in contexts context menus.
	 *
	 */
	init : function() {
		this.registerInsertionPoint('context.mail.contextmenu.options', this.putAcrhiveMenuIconInContextMenu, this)
	},

	/**
	 * Creates configured context menu item.
	 *
	 * @return {Zarafa.core.ui.menu.ConditionalItem} menuItem MenuItem instance
	 */
	putAcrhiveMenuIconInContextMenu : function() {
		var menuItem = {
			xtype       : 'zarafa.conditionalitem',
			text        : _('Archive to SugarCRM'),
			iconCls     : 'icon_sugarcrm_archive',
			handler     : this.showArchiveToSugarCRMDialog,
			scope       : this
		};
		return menuItem;
	},

	/**
	 * Send request to server after the user clicked on menu item.
	 * Opens the new window with returned url from server - in case of
	 * success.
	 *
	 */
	showArchiveToSugarCRMDialog : function() {
		//In current version we take only the last selected record
		var selectedRecords = container.getCurrentContext().getModel().getSelectedRecords();
		var lastRecord = selectedRecords.pop();
		container.getRequest().singleRequest('sugarcrmmodule', 'archive', {
			entryid : lastRecord.get('entryid'),
			parent_entryid : lastRecord.get('parent_entryid'),
			store_entryid : lastRecord.get('store_entryid'),
			profile : 'sugarcrm'
		}, new Zarafa.plugins.sugarcrm.data.SugarCRMResponseHandler());
	}


});

Zarafa.onReady(function() {
	if(container.getSettingsModel().get('zarafa/v1/plugins/sugarcrm/enable') === true) {
		container.registerPlugin( new Zarafa.plugins.sugarcrm.SugarCRMPlugin() );
	}
});